@@ -31,6 +31,7 @@ from gpt_index.readers.pinecone import PineconeReader
 from gpt_index.readers.qdrant import QdrantReader
 from gpt_index.readers.schema.base import Document
 from gpt_index.readers.slack import SlackReader
+from gpt_index.readers.steamship.file_reader import SteamshipFileReader
 from gpt_index.readers.string_iterable import StringIterableReader
 from gpt_index.readers.twitter import TwitterTweetReader
 from gpt_index.readers.weaviate.reader import WeaviateReader
@@ -70,4 +71,5 @@ __all__ = [
     "GithubRepositoryReader",
     "MboxReader",
     "ElasticsearchReader",
+    "SteamshipFileReader",
 ]
