@@ -1,5 +1,7 @@
 """Test list index."""
 
+import asyncio
+from copy import deepcopy
 from pathlib import Path
 from tempfile import TemporaryDirectory
 from typing import Any, Dict, List, Tuple, cast
@@ -13,9 +15,13 @@ from gpt_index.indices.query.list.embedding_query import GPTListIndexEmbeddingQu
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
 from gpt_index.langchain_helpers.text_splitter import TokenTextSplitter
 from gpt_index.readers.schema.base import Document
+from gpt_index.schema import BaseDocument
 from gpt_index.utils import globals_helper
 from tests.mock_utils.mock_decorator import patch_common
-from tests.mock_utils.mock_predict import mock_llmpredictor_predict
+from tests.mock_utils.mock_predict import (
+    mock_llmpredictor_apredict,
+    mock_llmpredictor_predict,
+)
 from tests.mock_utils.mock_prompts import MOCK_REFINE_PROMPT, MOCK_TEXT_QA_PROMPT
 
 
@@ -64,6 +70,45 @@ def test_build_list(
     assert list_index.index_struct.nodes[3].text == "This is a test v2."
 
 
+@patch_common
+def test_refresh_list(
+    _mock_init: Any,
+    _mock_predict: Any,
+    _mock_total_tokens_used: Any,
+    _mock_split_text_overlap: Any,
+    _mock_split_text: Any,
+    documents: List[BaseDocument],
+) -> None:
+    """Test build list."""
+    # add extra document
+    more_documents = documents + [Document("Test document 2")]
+
+    # ensure documents have doc_id
+    for i in range(len(more_documents)):
+        more_documents[i].doc_id = str(i)
+
+    # create index
+    list_index = GPTListIndex(documents=more_documents)
+
+    # check that no documents are refreshed
+    refreshed_docs = list_index.refresh(more_documents)
+    assert refreshed_docs[0] is False
+    assert refreshed_docs[1] is False
+
+    # modify a document and test again
+    more_documents = documents + [Document("Test document 2, now with changes!")]
+    for i in range(len(more_documents)):
+        more_documents[i].doc_id = str(i)
+
+    # second document should refresh
+    refreshed_docs = list_index.refresh(more_documents)
+    assert refreshed_docs[0] is False
+    assert refreshed_docs[1] is True
+    assert (
+        list_index.index_struct.nodes[-1].text == "Test document 2, now with changes!"
+    )
+
+
 @patch_common
 def test_build_list_multiple(
     _mock_init: Any,
@@ -366,3 +411,44 @@ def test_to_from_string(
     assert new_list_index.index_struct.nodes[1].text == "This is a test."
     assert new_list_index.index_struct.nodes[2].text == "This is another test."
     assert new_list_index.index_struct.nodes[3].text == "This is a test v2."
+
+
+@patch_common
+@patch.object(LLMPredictor, "apredict", side_effect=mock_llmpredictor_apredict)
+def test_async_query(
+    _mock_async_predict: Any,
+    _mock_init: Any,
+    _mock_predict: Any,
+    _mock_total_tokens_used: Any,
+    _mock_split_text_overlap: Any,
+    _mock_split_text: Any,
+    documents: List[Document],
+    struct_kwargs: Dict,
+) -> None:
+    """Test list async query."""
+    index_kwargs, query_kwargs = struct_kwargs
+    index = GPTListIndex(documents, **index_kwargs)
+
+    # test default query mode.
+    query_str = "What is?"
+    task = index.aquery(query_str, mode="default", **query_kwargs)
+    response = asyncio.run(task)
+    assert str(response) == ("What is?:Hello world.")
+    node_info = (
+        response.source_nodes[0].node_info if response.source_nodes[0].node_info else {}
+    )
+    assert node_info["start"] == 0
+    assert node_info["end"] == 12
+
+    # test tree_summarize mode
+    query_str = "What is?"
+    query_kwargs_copy = deepcopy(query_kwargs)
+    query_kwargs_copy["response_mode"] = "tree_summarize"
+    task = index.aquery(query_str, mode="default", **query_kwargs_copy)
+    response = asyncio.run(task)
+    assert str(response) == ("What is?:Hello world.")
+    node_info = (
+        response.source_nodes[0].node_info if response.source_nodes[0].node_info else {}
+    )
+    assert node_info["start"] == 0
+    assert node_info["end"] == 12
