@@ -16,9 +16,12 @@ from sqlalchemy import (
     select,
 )
 
-from gpt_index.indices.common.struct_store.base import SQLContextBuilder
+from gpt_index.indices.list.base import GPTListIndex
 from gpt_index.indices.struct_store.base import default_output_parser
-from gpt_index.indices.struct_store.sql import GPTSQLStructStoreIndex
+from gpt_index.indices.struct_store.sql import (
+    GPTSQLStructStoreIndex,
+    SQLContextContainerBuilder,
+)
 from gpt_index.langchain_helpers.sql_wrapper import SQLDatabase
 from gpt_index.readers.schema.base import Document
 from gpt_index.schema import BaseDocument
@@ -117,6 +120,13 @@ def test_sql_index(
         assert results == [(2, "bar"), (8, "hello")]
 
 
+def _delete_table_items(engine: Any, table: Table) -> None:
+    """Delete items from a table."""
+    delete_stmt = delete(table)
+    with engine.connect() as connection:
+        connection.execute(delete_stmt)
+
+
 @patch_common
 def test_sql_index_with_context(
     _mock_init: Any,
@@ -143,38 +153,65 @@ def test_sql_index_with_context(
     docs = [Document(text="user_id:2,foo:bar"), Document(text="user_id:8,foo:hello")]
     sql_database = SQLDatabase(engine)
     table_context_dict = {"test_table": "test_table_context"}
+
+    # test with ignore_db_schema=True
+    sql_context_container = SQLContextContainerBuilder(
+        sql_database, context_dict=table_context_dict
+    ).build_context_container(ignore_db_schema=True)
+
     index = GPTSQLStructStoreIndex(
         docs,
         sql_database=sql_database,
         table_name=table_name,
-        table_context_dict=table_context_dict,
+        sql_context_container=sql_context_container,
         **index_kwargs
     )
-    assert index._index_struct.context_dict == table_context_dict
+    assert index.sql_context_container.context_dict == table_context_dict
+    _delete_table_items(engine, test_table)
+
+    # test with ignore_db_schema=False (default)
+    sql_database = SQLDatabase(engine)
+    sql_context_container = SQLContextContainerBuilder(
+        sql_database, context_dict=table_context_dict
+    ).build_context_container()
+
+    index = GPTSQLStructStoreIndex(
+        docs,
+        sql_database=sql_database,
+        table_name=table_name,
+        sql_context_container=sql_context_container,
+        **index_kwargs
+    )
+    for k, v in table_context_dict.items():
+        context_dict = index.sql_context_container.context_dict
+        assert context_dict is not None
+        assert len(context_dict[k]) > len(v)
+        assert v in context_dict[k]
+    _delete_table_items(engine, test_table)
 
     # test setting sql_context_builder
-    delete_stmt = delete(test_table)
-    with engine.connect() as connection:
-        connection.execute(delete_stmt)
     sql_database = SQLDatabase(engine)
     # this should cause the mock QuestionAnswer prompt to run
-    sql_context_builder = SQLContextBuilder(
-        sql_database,
-        table_context_prompt=MOCK_TABLE_CONTEXT_PROMPT,
-        table_context_task="extract_test",
-    )
     context_documents_dict: Dict[str, List[BaseDocument]] = {
         "test_table": [Document("test_table_context")]
     }
+    sql_context_builder = SQLContextContainerBuilder.from_documents(
+        context_documents_dict,
+        sql_database=sql_database,
+        table_context_prompt=MOCK_TABLE_CONTEXT_PROMPT,
+        table_context_task="extract_test",
+    )
+    sql_context_container = sql_context_builder.build_context_container(
+        ignore_db_schema=True
+    )
     index = GPTSQLStructStoreIndex(
         docs,
         sql_database=sql_database,
         table_name=table_name,
-        sql_context_builder=sql_context_builder,
-        context_documents_dict=context_documents_dict,
+        sql_context_container=sql_context_container,
         **index_kwargs
     )
-    assert index._index_struct.context_dict == {
+    assert index.sql_context_container.context_dict == {
         "test_table": "extract_test:test_table_context"
     }
 
@@ -182,6 +219,102 @@ def test_sql_index_with_context(
     # TODO:
 
 
+@patch_common
+def test_sql_index_with_derive_index(
+    _mock_init: Any,
+    _mock_predict: Any,
+    _mock_total_tokens_used: Any,
+    _mock_split_text_overlap: Any,
+    _mock_split_text: Any,
+    struct_kwargs: Tuple[Dict, Dict],
+) -> None:
+    """Test derive index."""
+    # test setting table_context_dict
+    engine = create_engine("sqlite:///:memory:")
+    metadata_obj = MetaData(bind=engine)
+    table_name = "test_table"
+    Table(
+        table_name,
+        metadata_obj,
+        Column("user_id", Integer, primary_key=True),
+        Column("foo", String(16), nullable=False),
+    )
+    metadata_obj.create_all()
+    # NOTE: we can use the default output parser for this
+    sql_database = SQLDatabase(engine)
+    table_context_dict = {"test_table": "test_table_context"}
+
+    context_builder = SQLContextContainerBuilder(
+        sql_database, context_dict=table_context_dict
+    )
+    context_index_no_ignore = context_builder.derive_index_from_context(
+        GPTListIndex,
+    )
+    context_index_with_ignore = context_builder.derive_index_from_context(
+        GPTListIndex, ignore_db_schema=True
+    )
+    assert len(context_index_with_ignore.index_struct.nodes) == 1
+    assert len(context_index_no_ignore.index_struct.nodes) > 1
+
+
+@patch_common
+def test_sql_index_with_index_context(
+    _mock_init: Any,
+    _mock_predict: Any,
+    _mock_total_tokens_used: Any,
+    _mock_split_text_overlap: Any,
+    _mock_split_text: Any,
+    struct_kwargs: Tuple[Dict, Dict],
+) -> None:
+    """Test GPTSQLStructStoreIndex."""
+    # test setting table_context_dict
+    engine = create_engine("sqlite:///:memory:")
+    metadata_obj = MetaData(bind=engine)
+    table_name = "test_table"
+    Table(
+        table_name,
+        metadata_obj,
+        Column("user_id", Integer, primary_key=True),
+        Column("foo", String(16), nullable=False),
+    )
+    metadata_obj.create_all()
+    # NOTE: we can use the default output parser for this
+    index_kwargs, _ = struct_kwargs
+    docs = [Document(text="user_id:2,foo:bar"), Document(text="user_id:8,foo:hello")]
+    sql_database = SQLDatabase(engine)
+    table_context_dict = {"test_table": "test_table_context"}
+
+    context_builder = SQLContextContainerBuilder(
+        sql_database, context_dict=table_context_dict
+    )
+    context_index = context_builder.derive_index_from_context(
+        GPTListIndex, ignore_db_schema=True
+    )
+    # NOTE: the response only contains the first line (metadata), since
+    # with the mock patch, newlines are treated as separate calls.
+    context_response = context_builder.query_index_for_context(
+        context_index,
+        "Context query?",
+        query_tmpl="{orig_query_str}",
+        store_context_str=True,
+    )
+    sql_context_container = context_builder.build_context_container(
+        ignore_db_schema=True
+    )
+    assert context_response == "Context query?:table_name: test_table"
+    assert sql_context_container.context_str == context_response
+
+    index = GPTSQLStructStoreIndex(
+        docs,
+        sql_database=sql_database,
+        table_name=table_name,
+        sql_context_container=sql_context_container,
+        **index_kwargs
+    )
+    # just assert this runs
+    index.query("test_table:foo", mode="default")
+
+
 @patch_common
 def test_sql_index_query(
     _mock_init: Any,
