@@ -1,16 +1,19 @@
 """Test Faiss index."""
 
 import sys
-from typing import Any, Dict, List, Tuple
+from typing import Any, Dict, List, Tuple, cast
 from unittest.mock import MagicMock, patch
 
 import numpy as np
 import pytest
 
 from gpt_index.embeddings.openai import OpenAIEmbedding
-from gpt_index.indices.vector_store.faiss import GPTFaissIndex
-from gpt_index.indices.vector_store.simple import GPTSimpleVectorIndex
+from gpt_index.indices.vector_store.vector_indices import (
+    GPTFaissIndex,
+    GPTSimpleVectorIndex,
+)
 from gpt_index.readers.schema.base import Document
+from gpt_index.vector_stores.simple import SimpleVectorStore
 from tests.mock_utils.mock_decorator import patch_common
 from tests.mock_utils.mock_prompts import MOCK_REFINE_PROMPT, MOCK_TEXT_QA_PROMPT
 
@@ -106,6 +109,33 @@ def mock_get_text_embeddings(texts: List[str]) -> List[List[float]]:
     return [mock_get_text_embedding(text) for text in texts]
 
 
+async def mock_aget_text_embedding(text: str) -> List[float]:
+    """Mock async get text embedding."""
+    # assume dimensions are 5
+    if text == "Hello world.":
+        return [1, 0, 0, 0, 0]
+    elif text == "This is a test.":
+        return [0, 1, 0, 0, 0]
+    elif text == "This is another test.":
+        return [0, 0, 1, 0, 0]
+    elif text == "This is a test v2.":
+        return [0, 0, 0, 1, 0]
+    elif text == "This is a test v3.":
+        return [0, 0, 0, 0, 1]
+    elif text == "This is bar test.":
+        return [0, 0, 1, 0, 0]
+    elif text == "Hello world backup.":
+        # this is used when "Hello world." is deleted.
+        return [1, 0, 0, 0, 0]
+    else:
+        raise ValueError("Invalid text for `mock_aget_text_embedding`.")
+
+
+async def mock_aget_text_embeddings(texts: List[str]) -> List[List[float]]:
+    """Mock async get text embeddings."""
+    return [await mock_aget_text_embedding(text) for text in texts]
+
+
 def mock_get_query_embedding(query: str) -> List[float]:
     """Mock get query embedding."""
     return [0, 0, 1, 0, 0]
@@ -210,7 +240,7 @@ def test_faiss_query(
     faiss_index = MockFaissIndex()
 
     index_kwargs, query_kwargs = struct_kwargs
-    index = GPTFaissIndex(documents, faiss_index=faiss_index, **index_kwargs)
+    index = GPTFaissIndex(documents=documents, faiss_index=faiss_index, **index_kwargs)
 
     # test embedding query
     query_str = "What is?"
@@ -236,7 +266,7 @@ def test_build_simple(
     documents: List[Document],
     struct_kwargs: Dict,
 ) -> None:
-    """Test build GPTFaissIndex."""
+    """Test build GPTSimpleVectorIndex."""
     index_kwargs, query_kwargs = struct_kwargs
 
     index = GPTSimpleVectorIndex(documents=documents, **index_kwargs)
@@ -250,7 +280,9 @@ def test_build_simple(
     ]
     for text_id in index.index_struct.id_map.keys():
         node = index.index_struct.get_node(text_id)
-        embedding = index.index_struct.embedding_dict[text_id]
+        # NOTE: this test breaks abstraction
+        assert isinstance(index._vector_store, SimpleVectorStore)
+        embedding = index._vector_store.get(text_id)
         assert (node.text, embedding) in actual_node_tups
 
 
@@ -272,7 +304,7 @@ def test_simple_insert(
     documents: List[Document],
     struct_kwargs: Dict,
 ) -> None:
-    """Test build GPTFaissIndex."""
+    """Test insert GPTSimpleVectorIndex."""
     index_kwargs, query_kwargs = struct_kwargs
 
     index = GPTSimpleVectorIndex(documents=documents, **index_kwargs)
@@ -289,7 +321,9 @@ def test_simple_insert(
     ]
     for text_id in index.index_struct.id_map.keys():
         node = index.index_struct.get_node(text_id)
-        embedding = index.index_struct.embedding_dict[text_id]
+        # NOTE: this test breaks abstraction
+        assert isinstance(index._vector_store, SimpleVectorStore)
+        embedding = index._vector_store.get(text_id)
         assert (node.text, embedding) in actual_node_tups
 
 
@@ -311,7 +345,7 @@ def test_simple_delete(
     documents: List[Document],
     struct_kwargs: Dict,
 ) -> None:
-    """Test build GPTFaissIndex."""
+    """Test delete GPTSimpleVectorIndex."""
     index_kwargs, query_kwargs = struct_kwargs
 
     new_documents = [
@@ -333,7 +367,9 @@ def test_simple_delete(
     ]
     for text_id in index.index_struct.id_map.keys():
         node = index.index_struct.get_node(text_id)
-        embedding = index.index_struct.embedding_dict[text_id]
+        # NOTE: this test breaks abstraction
+        assert isinstance(index._vector_store, SimpleVectorStore)
+        embedding = index._vector_store.get(text_id)
         assert (node.text, embedding, node.ref_doc_id) in actual_node_tups
 
     # test insert
@@ -348,7 +384,9 @@ def test_simple_delete(
     ]
     for text_id in index.index_struct.id_map.keys():
         node = index.index_struct.get_node(text_id)
-        embedding = index.index_struct.embedding_dict[text_id]
+        # NOTE: this test breaks abstraction
+        assert isinstance(index._vector_store, SimpleVectorStore)
+        embedding = index._vector_store.get(text_id)
         assert (node.text, embedding, node.ref_doc_id) in actual_node_tups
 
 
@@ -517,3 +555,40 @@ def test_query_and_similarity_scores_with_cutoff(
     query_str = "What is?"
     response = index.query(query_str, similarity_cutoff=0.9, **query_kwargs)
     assert len(response.source_nodes) == 1
+
+
+@patch_common
+@patch.object(
+    OpenAIEmbedding, "_aget_text_embedding", side_effect=mock_aget_text_embedding
+)
+@patch.object(
+    OpenAIEmbedding, "_aget_text_embeddings", side_effect=mock_aget_text_embeddings
+)
+def test_simple_async(
+    _mock_embeds: Any,
+    _mock_embed: Any,
+    _mock_init: Any,
+    _mock_predict: Any,
+    _mock_total_tokens_used: Any,
+    _mock_split_text_overlap: Any,
+    _mock_split_text: Any,
+    documents: List[Document],
+    struct_kwargs: Dict,
+) -> None:
+    """Test simple vector index with use_async."""
+    index_kwargs, query_kwargs = struct_kwargs
+
+    index = GPTSimpleVectorIndex(documents=documents, use_async=True, **index_kwargs)
+    assert len(index.index_struct.nodes_dict) == 4
+    # check contents of nodes
+    actual_node_tups = [
+        ("Hello world.", [1, 0, 0, 0, 0]),
+        ("This is a test.", [0, 1, 0, 0, 0]),
+        ("This is another test.", [0, 0, 1, 0, 0]),
+        ("This is a test v2.", [0, 0, 0, 1, 0]),
+    ]
+    for text_id in index.index_struct.id_map.keys():
+        node = index.index_struct.get_node(text_id)
+        vector_store = cast(SimpleVectorStore, index._vector_store)
+        embedding = vector_store.get(text_id)
+        assert (node.text, embedding) in actual_node_tups
